@@ -67,6 +67,8 @@ typedef enum {
   should release the old value and retain the new one. It is nil originally
   and will be released when the NSLayoutManager is deallocated. */
   NSMutableDictionary *_typingAttributes;
+
+  NSMutableAttributedString *_temporaryAttributes;
 }
 
 /* TODO */
@@ -97,17 +99,17 @@ typedef enum {
 - (void) textContainerChangedTextView: (NSTextContainer *)aContainer;
 
 
-- (NSPoint) locationForGlyphAtIndex: (unsigned int)glyphIndex;
+- (NSPoint) locationForGlyphAtIndex: (NSUInteger)glyphIndex;
 
 
 - (NSRect *) rectArrayForGlyphRange: (NSRange)glyphRange
 	withinSelectedGlyphRange: (NSRange)selGlyphRange
 	inTextContainer: (NSTextContainer *)container
-	rectCount: (unsigned int *)rectCount;
+	rectCount: (NSUInteger *)rectCount;
 - (NSRect *) rectArrayForCharacterRange: (NSRange)charRange
 	withinSelectedCharacterRange: (NSRange)selCharRange
 	inTextContainer: (NSTextContainer *)container
-	rectCount: (unsigned int *)rectCount;
+	rectCount: (NSUInteger *)rectCount;
 
 - (NSRect) boundingRectForGlyphRange: (NSRange)glyphRange 
 	inTextContainer: (NSTextContainer *)aTextContainer;
@@ -180,7 +182,17 @@ GNUstep extension.
 -(void) drawGlyphsForGlyphRange: (NSRange)range
 	atPoint: (NSPoint)containerOrigin;
 
-/* TODO: underline */
+-(void) underlineGylphRange: (NSRange)range
+              underlineType: (NSInteger)type
+           lineFragmentRect: (NSRect)fragmentRect
+     lineFragmentGlyphRange: (NSRange)fragmentGlyphRange
+	    containerOrigin: (NSPoint)containerOrigin;
+-(void) drawUnderlineForGlyphRange: (NSRange)underlineRange
+                     underlineType: (NSInteger)type
+                    baselineOffset: (CGFloat)offset
+                  lineFragmentRect: (NSRect)fragmentRect
+            lineFragmentGlyphRange: (NSRange)fragmentGlyphRange
+	           containerOrigin: (NSPoint)containerOrigin;
 
 - (NSSize) attachmentSizeForGlyphAtIndex: (NSUInteger)glyphIndex;
 - (void) showAttachmentCell: (NSCell *)cell
@@ -190,14 +202,30 @@ GNUstep extension.
 @end
 
 @interface NSLayoutManager (temporaryattributes)
-- (void) addTemporaryAttributes: (NSDictionary *)attrs forCharacterRange: (NSRange)range;
-- (void) addTemporaryAttribute: (NSString *)attr value: (id)value forCharacterRange: (NSRange)range;
-- (void) setTemporaryAttributes:forCharacterRange: (NSRange)range;
-- (void) removeTemporaryAttribute: (NSString *)attr forCharacterRange: (NSRange)range;
-- (id) temporaryAttribute: (NSString *)attr atCharacterIndex: (unsigned int)index effectiveRange: (NSRange)range;
-- (id) temporaryAttribute: (NSString *)attr atCharacterIndex: (unsigned int)index longestEffectiveRange: (NSRange*)longestRange inRange: (NSRange)range;
-- (NSDictionary *) temporaryAttributesAtCharacterIndex: (unsigned int)index effectiveRange: (NSRange)range;
-- (NSDictionary *) temporaryAttributesAtCharacterIndex: (unsigned int) longestEffectiveRange: (NSRange*)longestRange inRange: (NSRange)range;
+- (void) addTemporaryAttributes: (NSDictionary *)attrs 
+              forCharacterRange: (NSRange)range;
+- (void) removeTemporaryAttribute: (NSString *)attr 
+                forCharacterRange: (NSRange)range;
+- (void) setTemporaryAttributes: (NSDictionary *)attrs 
+              forCharacterRange: (NSRange)range;
+- (NSDictionary *) temporaryAttributesAtCharacterIndex: (NSUInteger)index 
+                                        effectiveRange: (NSRange*)range;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (void) addTemporaryAttribute: (NSString *)attr 
+                         value: (id)value 
+             forCharacterRange: (NSRange)range;
+- (id) temporaryAttribute: (NSString *)attr 
+         atCharacterIndex: (NSUInteger)index 
+           effectiveRange: (NSRange*)range;
+- (id) temporaryAttribute: (NSString *)attr 
+         atCharacterIndex: (NSUInteger)index 
+    longestEffectiveRange: (NSRange*)longestRange 
+                  inRange: (NSRange)range;
+- (NSDictionary *) temporaryAttributesAtCharacterIndex: (NSUInteger)index
+                                 longestEffectiveRange: (NSRange*)longestRange 
+                                               inRange: (NSRange)range;
+#endif
 @end
 #endif
 
