@@ -79,6 +79,7 @@ enum {
   BOOL _canCreateDirectories;
   BOOL _canSelectHiddenExtension;
   BOOL _isExtensionHidden;
+  BOOL _showsHiddenFiles;
 
   BOOL _delegateHasCompareFilter;
   BOOL _delegateHasShowFilenameFilter;
@@ -89,6 +90,8 @@ enum {
 
   // YES when we stopped because the user pressed 'OK'
   BOOL _OKButtonPressed;
+
+  NSMenu *_showsHiddenFilesMenu;
 }
 
 /*
@@ -121,6 +124,11 @@ enum {
 - (void) setExtensionHidden: (BOOL) flag;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (BOOL) showsHiddenFiles;
+- (void) setShowsHiddenFiles: (BOOL) flag;
+#endif
+
 /*
  * Setting Directory and File Type
  */
