@@ -30,11 +30,12 @@
 #ifndef _GNUstep_H_NSWorkspace
 #define _GNUstep_H_NSWorkspace
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSGeometry.h>
-#include <AppKit/AppKitDefines.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSGeometry.h>
+#import <AppKit/AppKitDefines.h>
 
 @class NSString;
+@class NSNumber;
 @class NSArray;
 @class NSMutableArray;
 @class NSMutableDictionary;
@@ -43,6 +44,26 @@
 @class NSView;
 @class NSURL;
 
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+enum {
+  NSWorkspaceLaunchAndPrint                  = 0x2,
+  NSWorkspaceLaunchInhibitingBackgroundOnly  = 0x80,
+  NSWorkspaceLaunchWithoutAddingToRecents    = 0x100,
+  NSWorkspaceLaunchWithoutActivation         = 0x200,
+  NSWorkspaceLaunchAsync                     = 0x10000,
+  NSWorkspaceLaunchAllowingClassicStartup    = 0x20000,
+  NSWorkspaceLaunchPreferringClassic         = 0x40000,
+  NSWorkspaceLaunchNewInstance               = 0x80000,
+  NSWorkspaceLaunchAndHide                   = 0x100000,
+  NSWorkspaceLaunchAndHideOthers             = 0x200000,
+  NSWorkspaceLaunchDefault                   = NSWorkspaceLaunchAsync | NSWorkspaceLaunchAllowingClassicStartup
+};
+
+typedef NSUInteger NSWorkspaceLaunchOptions;
+#endif
+
+
 @interface NSWorkspace : NSObject
 {
   NSMutableDictionary	*_iconMap;
@@ -128,6 +149,17 @@
 - (BOOL) launchApplication: (NSString*)appName
 		  showIcon: (BOOL)showIcon
 		autolaunch: (BOOL)autolaunch;
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+// TODO: implement NSAppleEventDescriptor in gnustep-base
+typedef void NSAppleEventDescriptor;
+
+- (BOOL) launchAppWithBundleIdentifier: (NSString *)bundleIdentifier
+			       options: (NSWorkspaceLaunchOptions)options 
+	additionalEventParamDescriptor: (NSAppleEventDescriptor *)descriptor 
+		      launchIdentifier: (NSNumber **)identifier;
+#endif
+
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSDictionary*) activeApplication;
 - (NSArray*) launchedApplications;
@@ -189,6 +221,12 @@
 	     inRole: (NSString*)role
        forExtension: (NSString*)ext;
 - (void) setBestIcon: (NSString*)iconPath forExtension: (NSString*)ext;
+- (NSDictionary*) infoForScheme: (NSString*)scheme;
+- (NSString*) getBestAppInRole: (NSString*)role
+		     forScheme: (NSString*)scheme;
+- (void) setBestApp: (NSString*)appName
+	     inRole: (NSString*)role
+	  forScheme: (NSString*)scheme;
 @end
 #endif
 
